CheckoutTheme class

Theme values for CheckoutPage and related widgets.

Apply with ThemeData.extensions:

theme: ThemeData(
  extensions: const [CheckoutTheme()],
),
Inheritance

Constructors

CheckoutTheme({Color? appBarBackgroundColor, Color? collapsedTitleColor, Color? chargeAmountColor, Color? nativePayBackgroundColor, Color? nativePayForegroundColor, Color? cashPayBackgroundColor, Color? cashPayForegroundColor})
const

Properties

appBarBackgroundColor Color?
SliverAppBar.backgroundColor when not null.
final
cashPayBackgroundColor Color?
final
cashPayForegroundColor Color?
final
chargeAmountColor Color?
Color of the main charge amount figure.
final
collapsedTitleColor Color?
Title text color in the app bar.
final
hashCode int
The hash code for this object.
no setterinherited
nativePayBackgroundColor Color?
final
nativePayForegroundColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? appBarBackgroundColor, Color? collapsedTitleColor, Color? chargeAmountColor, Color? nativePayBackgroundColor, Color? nativePayForegroundColor, Color? cashPayBackgroundColor, Color? cashPayForegroundColor}) CheckoutTheme
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<CheckoutTheme>? other, double t) CheckoutTheme
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) CheckoutTheme