CardPayButton constructor

const CardPayButton({
  1. Key? key,
  2. required void onPressed(),
  3. CardPayButtonStatus? initStatus,
  4. required String text,
})

Button representing the option to submit the credit card info and start the process of a payment.

Implementation

const CardPayButton({
  super.key,
  required this.onPressed,
  this.initStatus,
  required this.text,
});